@@ -2,11 +2,11 @@ from hts.core.regressor import HTSRegressor
 from hts.revision import RevisionMethod
 
 __author__ = """Carlo Mazzaferro"""
-__email__ = 'carlo.mazzaferro@gmail.com'
-__version__ = '0.5.3'
+__email__ = "carlo.mazzaferro@gmail.com"
+__version__ = "0.5.4"
 
 
 __all__ = [
-    'HTSRegressor',
-    'RevisionMethod',
+    "HTSRegressor",
+    "RevisionMethod",
 ]
