@@ -10,23 +10,21 @@ def test_convenience_error_handling(load_df_and_hier_uv):
     hd, hier = load_df_and_hier_uv
     dummy = numpy.array([1, 2, 3, 5])
     with pytest.raises(ValueError):
-        revise_forecasts('FP', forecasts={'a': dummy}, nodes=None)
+        revise_forecasts("FP", forecasts={"a": dummy}, nodes=None)
 
     with pytest.raises(ValueError):
-        revise_forecasts('OLS',
-                         summing_matrix=dummy,
-                         forecasts={'a': dummy})
+        revise_forecasts("OLS", summing_matrix=dummy, forecasts={"a": dummy})
 
 
 def test_convenience(load_df_and_hier_uv):
     hd, hier = load_df_and_hier_uv
     hd = hd.head(200)
-    ht = HTSRegressor(model='holt_winters', revision_method='OLS')
+    ht = HTSRegressor(model="holt_winters", revision_method="OLS")
     ht = ht.fit(df=hd, nodes=hier)
     preds = ht.predict(steps_ahead=10)
 
     rev = revise_forecasts(
-        'OLS',
+        "OLS",
         nodes=ht.nodes,
         forecasts=ht.hts_result.forecasts,
         errors=ht.hts_result.errors,
@@ -37,7 +35,7 @@ def test_convenience(load_df_and_hier_uv):
     assert numpy.allclose(preds.values, rev.values)
 
     rev_s = revise_forecasts(
-        'OLS',
+        "OLS",
         summing_matrix=ht.sum_mat,
         forecasts=ht.hts_result.forecasts,
         errors=ht.hts_result.errors,
@@ -46,10 +44,5 @@ def test_convenience(load_df_and_hier_uv):
     assert isinstance(rev_s, pandas.DataFrame)
     assert numpy.allclose(rev.values, rev_s.values)
 
-    rev = revise_forecasts(
-        'AHP',
-        nodes=ht.nodes,
-        forecasts=ht.hts_result.forecasts
-    )
+    rev = revise_forecasts("AHP", nodes=ht.nodes, forecasts=ht.hts_result.forecasts)
     assert isinstance(rev, pandas.DataFrame)
-
